use strict;
use utf8;
use warnings;

package noris::Ticket::API::RT::Field::String;

use Dbase::Help qw(like_list);
use Moose;

extends 'noris::Ticket::API::RT::Field::Standard';

sub where_like {
    my $self = shift;
    like_list( $self->db_name, '', $self->_map_wildcards(@_) );
}

sub where_like_not {
    my $self = shift;
    like_list( $self->db_name, NOT => $self->_map_wildcards(@_) );
}

1;
